#
# spec file for package ipsec-tools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           ipsec-tools
Version:        0.8.2
Release:        lp150.4.7
Summary:        IPsec Utilities
License:        BSD-3-Clause
Group:          Productivity/Networking/Security
Url:            http://ipsec-tools.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/ipsec-tools/ipsec-tools-%{version}.tar.bz2
Source2:        sysconfig.racoon
Source3:        setkey.conf.sample
Source4:        racoon.pam
Source5:        racoon.service
Source6:        racoon-setkey.service
Patch0:         racoon.conf_macros.patch
Patch1:         racoon.psk.patch
Patch2:         ipsec-tools-0.7.3-linkerflag.patch
Patch3:         ipsec-tools-0.8.0-nodevel.patch
Patch4:         ipsec-tools-0.8.0-certasn1txtbroken.patch
Patch5:         racoon-fips-rsa.patch
Patch6:         racoon-no-md5.patch
Patch7:         ipsec-tools-openssl1.1.patch
Patch8:         avoid-dos-with-fragment-out-of-order.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  krb5-devel
BuildRequires:  libselinux-devel
BuildRequires:  libtool
BuildRequires:  linux-glibc-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pam
BuildRequires:  pam-devel
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(systemd)
Requires(post): %fillup_prereq
Provides:       racoon
%{?systemd_requires}

%description
This is the IPsec-Tools package.  This package is needed to really make
use of the IPsec functionality in the version 2.5 and 2.6 Linux
kernels.  This package builds:
  - libipsec, a PFKeyV2 library
  - setkey, a program to directly manipulate policies and SAs
  - racoon, an IKEv1 keying daemon
These sources can be found at the IPsec-Tools home page at:
http://ipsec-tools.sourceforge.net/

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
if pkg-config --atleast-version=1.1.0 libssl; then
%patch7 -p1
fi
%patch8

./bootstrap
sed -i 's|-Werror||g' configure

%build
%configure \
	--disable-shared \
	--libexecdir=%{_libdir} \
	--sysconfdir=%{_sysconfdir}/racoon \
	--sharedstatedir=/run \
	--localstatedir=/run \
	--with-kernel-headers="%{_prefix}/include" \
	--enable-dpd \
	--enable-hybrid \
	--enable-frag \
	--enable-natt=yes \
	--enable-gssapi=yes \
	--enable-stats=yes \
	--enable-adminport \
	--with-libpam \
	--enable-security-context=yes \
	--with-libldap
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/pam.d/racoon
install -d %{buildroot}%{_sysconfdir}/racoon/cert
# unify the permissions of psk.txt - fdupes is sensitive on permissions now (bnc#784670)
chmod 0600 src/racoon/samples/psk.txt
install -m 0600 src/racoon/samples/psk.txt %{buildroot}%{_sysconfdir}/racoon/
install -m 0644 src/racoon/samples/racoon.conf %{buildroot}%{_sysconfdir}/racoon/
cp -v $RPM_SOURCE_DIR/setkey.conf.sample %{buildroot}%{_sysconfdir}/racoon/setkey.conf
mkdir -p %{buildroot}%{_fillupdir}
install -m 644 $RPM_SOURCE_DIR/sysconfig.racoon %{buildroot}%{_fillupdir}/
# manage doc
mkdir -p %{buildroot}%{_docdir}/%{name}/examples/{setkey,racoon}
cp -rv src/racoon/samples %{buildroot}%{_docdir}/%{name}/examples/racoon
cp -v src/setkey/sample* %{buildroot}%{_docdir}/%{name}/examples/setkey
for i in ChangeLog NEWS README; do
	install -D -m 0644 $i %{buildroot}%{_docdir}/%{name}/
done
# systemd magic
install -d %{buildroot}%{_tmpfilesdir}
echo 'd /run/racoon 0700 root root -' > %{buildroot}%{_tmpfilesdir}/racoon.conf
install -D -m 0644 %{SOURCE5} %{buildroot}%{_unitdir}/racoon.service
install -D -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/racoon-setkey.service
ln -s service %{buildroot}%{_sbindir}/rcracoon
ln -s service %{buildroot}%{_sbindir}/rcracoon-setkey

# do not fdupe the whole tree, otherwise it might symlink /etc config files into /usr
%fdupes -s %{buildroot}/usr

%pre
%service_add_pre racoon.service racoon-setkey.service

%post
%{fillup_only -n racoon}
%tmpfiles_create %{_tmpfilesdir}/racoon.conf
%service_add_post racoon.service racoon-setkey.service

%preun
%service_del_preun racoon.service racoon-setkey.service

%postun
%service_del_postun racoon.service racoon-setkey.service

%files
%defattr(-,root,root)
%{_unitdir}/*.service
%{_sbindir}/rcracoon
%{_sbindir}/rcracoon-setkey
%{_tmpfilesdir}/racoon.conf
%doc %{_docdir}/%{name}/
%config(noreplace) %{_sysconfdir}/racoon/psk.txt
%config(noreplace) %{_sysconfdir}/racoon/racoon.conf
%config(noreplace) %{_sysconfdir}/racoon/setkey.conf
%config %{_sysconfdir}/pam.d/racoon
%dir %{_sysconfdir}/racoon
%dir %{_sysconfdir}/racoon/cert
%{_sbindir}/racoon
%{_sbindir}/racoonctl
%{_sbindir}/setkey
%{_sbindir}/plainrsa-gen
%{_fillupdir}/sysconfig.racoon
%{_mandir}/man*/*
%ghost /run/racoon

%changelog
* Fri Jan 26 2018 jbohac@suse.com
- avoid-dos-with-fragment-out-of-order.patch (bsc#1047443,
  CVE-2016-10396)
* Wed Nov 29 2017 meissner@suse.com
- ipsec-tools-openssl1.1.patch: build against openssl 1.1 (bsc#1066950)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sat Sep  2 2017 chris@computersalat.de
- add reminder for racoon-setkey.service to setkey.conf
* Wed Aug  5 2015 meissner@suse.com
- do not run %%fdupes over the whole tree, to avoid symlinking
  /etc/ config files and /usr/ sample configs.
* Wed Jun 10 2015 chris@computersalat.de
- rework racoon.psk.patch
  * comment example entry (its not a backdoor just an example)
* Thu Jun  4 2015 tchvatal@suse.com
- Cleanup most of the rpmlint warnings to have it in better shape
* Thu Apr 23 2015 meissner@suse.com
- racoon-fips-rsa.patch: Use a default exponent of at least 65537
  (minimum FIPS required public exponent)
- racoon-no-md5.patch: replace one md5 usage by sha1 in an internal
  hash table. Allow md5 usage for an external visible interface,
  as it is also hashing only.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 0.8.2
  * Fix admin port establish-sa for tunnel mode SAs
  * Fix source port selection regression from version 0.8.1
  * Various logging improvements
  * Additional compliance and build fixes
- Changes from version 0.8.1
  * Improved X.509 subject name comparation
  * Relax DPD cookie check for Cisco IOS compatibility
  * Allow simplified syntax for inherited remote blocks
  * Never shring pfkey socket buffer
  * Privilege separation child process exit fix
  * Multiple memory allocation and use-after-free fixes
- Remove some obsolete macros
* Tue Jul  8 2014 meissner@suse.com
- ipsec-tools-0.8.0-certasn1txtbroken.patch:
  disable the certificate test in src/racoon/eaytest.c as the
  internal X.509 ASN.1 string presentation was changed in openssl
  and the test currently does not work.
* Thu Mar 13 2014 jbohac@suse.cz
- add RemainAfterExit=yes to the .service file (bnc#856625)
* Fri Jan 10 2014 jbohac@suse.cz
- upgrade to version 0.8.0:
  o Fix authentication method ambiguity with kerberos and xauth
  o RFC2253 compliant escaping of asn1dn identifiers (Cyrus Rahman)
  o Local address code rewrite to speed things up
  o Improved MIPv6 support (Arnaud Ebalard)
  o ISAKMP SA (phase1) rekeying
  o Improved scheduler (faster algorithm, support monotonic clock)
  o Handle RESPONDER-LIFETIME in quick mode
  o Handle INITIAL-CONTACT in from main mode too
  o Rewritten event handling framework for admin port
  o Ability to initiate IPsec SA through admin port
  o NAT-T Original Address handling (transport mode NAT-T support)
  o clean NAT-T - PFkey support
  o support for multiple anonymous remoteconfs
  o Remove various obsolete configuration options
  o A lot of other bug fixes, performance improvements and clean ups
- Remove ipsec-tools-linux-3.7-compat.diff which caused bnc#867055
  by including wrong headers; fix by installing
  linux-glibc-devel and including /usr/include for kernel headers
* Thu Sep 19 2013 crrodriguez@opensuse.org
- remove unused racoon.init from the package, it was
  already removed from the spec file in the previous change.
* Thu Sep 19 2013 crrodriguez@opensuse.org
- Add systemd support, systemctl enable racoon.service
  also enables helper optional service racoon-setkey
- /etc/sysconfig/racoon was never created, fix that.
* Thu Jan 31 2013 mlin@suse.com
- Add ipsec-tools-linux-3.7-compat.diff(partly from openwrt)
  * since pfkeyv2.h moved to include/uapi/linux as
    http://lwn.net/Articles/507794/ explained, make the compiler found
    header in valid path. there is a discussion about this issue at
    https://dev.openwrt.org/ticket/12813
* Wed Oct 31 2012 mvyskocil@suse.com
- unify the permissions of psk.txt to avoid false duplicate warnings
  from fdupes (bnc#784670)
* Tue Jan 31 2012 meissner@suse.de
- remove suse_update_config macro usage
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep  4 2011 mkubecek@suse.cz
- create /var/run/racoon in the init script rather than including
  it in the package as it doesn't work if /var/run is on tmpfs
  (bnc#710277)
* Sun May 15 2011 chris@computersalat.de
- remove Author from description
- add racoon.psk patch
* Wed May  4 2011 idoenmez@novell.com
- Add ipsec-tools-0.7.3-linkerflag.patch: remove wrong linker flag
- Add ipsec-tools-0.7.2-nodevel.patch: don't install development
  files, instead of manually removing them in the spec file.
- Drop no_werror.patch: Remove Werror flag by sed, its all over the
  configure file, old patch was incomplete anyway.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Oct  6 2009 chris@computersalat.de
- cleanup spec
  o sorted sections
  o simplify clean
  o sort install section
  o sort files section
- added missing /etc/racoon/cert DIR
* Fri Sep 18 2009 chris@computersalat.de
- cleanup spec
  o sorted TAGS
  o added configure macro
- rpmlint
  o added fdupes
- fix selinux build
  o if suse_version >= 1100
* Thu Jun 11 2009 jbohac@suse.cz
- upgrade to 0.7.3
- integrated security patch
- enabled selinux support (--enable-security-context=yes)
* Thu Jun 11 2009 jbohac@suse.cz
- fix_sockaddr_overflow_in_ipsec_doi.c.diff (bnc#506710)
* Wed May  6 2009 jbohac@suse.cz
- Upgrade to 0.7.2
- fixed some rpmlint warnings/errors
- racoon.conf_macros.patch updates the .in file, not the result
- added /etc/pam.d/racoon
- added --with-libldap
* Tue Sep 23 2008 jbohac@suse.cz
- fixed a memory leak in PH1 (bnc#416906, CVE-2008-3652)
* Thu Aug 14 2008 jbohac@suse.cz
- Upgrade to 0.7.1
  o Fixes a memory leak when invalid proposal received
  o Some fixes in DPD
  o do not set default gss id if xauth is used
  o fixed hybrid enabled builds
  o fixed compilation on FreeBSD8
  o cleanup in network port value manipulation
  o gets ports from SADB_X_EXT_NAT_T_[SD]PORT if present in purge_ipsec_spi()
  o Generates a log if cert validation has been disabled by configuration
  o better handling for pfkey socket read errors
  o Fixes in yacc / bison stuff
  o new plog() macro (reduced CPU usage when logging is disabled)
  o Try to works better with huge SPD/SAD
  o Corrected modecfg option syntax
  o Many other various fixes...
* Wed Nov  7 2007 jbohac@suse.cz
- Upgrade to 0.7
* Thu Apr 12 2007 jbohac@jikos.cz
- Fix a DoS in isakmp_info_recv (CVE-2007-1841, 260791)
* Thu Mar 29 2007 aj@suse.de
- Add flex and bison to BuildRequires.
* Thu May  4 2006 jbohac@suse.cz
- fixed a segfault in GSSAPI initialization (#172196)
* Thu May  4 2006 jbohac@suse.cz
- the /var/run/racoon directory was missing from the package
  which prevented racoon from starting (#170552) - fixed
- fixed unexpanded macros in racoon.conf (#170552)
* Tue Mar 21 2006 jbohac@suse.cz
- upgrade to 0.6.5 (bugfix release)
  - Fixed zombie PH1 handler when isakmp_send() fails in
    isakmp_ph1resend()
  - Temporary fix for /32 subnets parsing.
  - make software behave as the documentation advertise for
    INTERNAL_NETMASK4. Keep the old INTERNAL_MASK4 to
    avoid breaking backward compatibility.
  - Fixed / cleaned up signal handling.
- added --with-libpam and --enable-adminport (#159647)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 13 2005 jbohac@suse.cz
- fixed build
* Tue Dec 13 2005 jbohac@suse.cz
- upgrade to 0.6.4
- added krb5 support ( --enable-gssapi)
- added statistics logging support ( --enable-stats)
* Wed Nov 23 2005 jbohac@suse.cz
- upgrade to 0.6.3 - fixes #134834 and an openssl incompatibility
  issue
* Tue Nov  8 2005 jbohac@suse.cz
- fixed build for s390
* Thu Oct 20 2005 jbohac@suse.cz
- upgraded to version 0.6.2
- enabled NAT-T
- fixed build with current openssl
* Wed Aug 31 2005 jbohac@suse.cz
- fixed permissions for /etc/racoon/psk.txt (bug #114383)
* Tue Aug 23 2005 jbohac@suse.cz
- upgrade to version 0.6.1
* Wed Aug  3 2005 jbohac@suse.cz
- fixed build on beta (disabled -Werror again)
* Tue Aug  2 2005 cthiel@suse.de
- fixed build
* Tue Aug  2 2005 jbohac@suse.cz
- upgrade to version 0.6
* Thu May  5 2005 jbohac@suse.cz
- upgrade to version 0.5.2
- disabled -Werror, because bison-generated code would not compile
* Wed Apr 13 2005 jbohac@suse.cz
- upgrade to version 0.5.1
- fixed compilation warning/errors regarding char/int signedness
* Wed Apr 13 2005 jbohac@suse.cz
- upgrade to version 0.5.1
- fixed compilation warning/errors regarding char/int signedness
* Wed Mar 16 2005 jbohac@suse.cz
  The patch in the previous release was not applied correctly; fixed.
* Tue Mar 15 2005 jbohac@suse.cz
- security fix - insecure header parsing (Bug ID: 64726)
* Sat Feb 19 2005 lmuelle@suse.de
- Update to version 0.5.
* Wed Jan  5 2005 jbohac@suse.cz
- update to ipsec-tools-0.5-rc1
* Thu Nov 18 2004 mludvig@suse.cz
- Update to version 0.4
* Mon Sep 13 2004 ro@suse.de
- undef __P first to make it build
* Tue Aug 10 2004 mludvig@suse.cz
- Update to 0.4rc1
* Tue Jun 15 2004 mludvig@suse.cz
- Update to 0.3.3 to fix a X.509 cert verification security bug.
  (http://marc.theaimsgroup.com/?l=bugtraq&m=108726102304507&w=2)
* Mon May 17 2004 mludvig@suse.cz
- Fixed comment in racoon.conf (#40576)
* Wed Apr 21 2004 mludvig@suse.cz
- Update to 0.3.1 to fix CAN-2004-0403
* Thu Apr 15 2004 mludvig@suse.cz
- Update to final 0.3. We had all patches in the
  package anyway...
* Thu Apr  8 2004 mludvig@suse.cz
- Fixed setkey to support multiline commands in interactive mode.
- Added 'exit' command to setkey.
  The two changes fix TAHI/ipsec tests.
- Emit messages about Keep-Alive packets with DEBUG severity
  instead of INFO. With INFO it only polutes syslog every 20s.
* Mon Apr  5 2004 mludvig@suse.cz
- Fixed X.509 security bug (#38373)
* Thu Apr  1 2004 mludvig@suse.cz
- Report received SADB_X_NAT_T_NEW_MAPPING message.
- Avoid segfault with unknown PF_KEY messages.
- Move encmode update out of the loop. NAT-T now works
  even with more than one proposal.
* Tue Mar 30 2004 mludvig@suse.cz
- Rewritten the testsuite to avoid
  failures on 32b platforms.
* Fri Mar 26 2004 mludvig@suse.cz
- Handle input lines one by one in interactive mode
  (preventing premature exit on syntax error).
* Thu Mar 25 2004 mludvig@suse.cz
- Update to 0.3rc4:
  - Fixed adding "null" encryption via 'setkey'.
  - Fixed segfault when using AES in Phase1 with OpenSSL>=0.9.7
  - Fixed NAT-T in aggresive mode.
  - Fixed testsuite and added testsuite run into make check.
* Tue Mar 23 2004 mludvig@suse.cz
- Fix segfault with AES.
- Enable testsuite.
* Mon Mar 22 2004 mludvig@suse.cz
- Fix "null" encryption setup in setkey.
* Fri Mar 19 2004 mludvig@suse.cz
- Fix duplicate ipsec service (#36575)
- Update to 0.3rc3
* Thu Mar 11 2004 mludvig@suse.cz
- Update to 0.3rc2
* Mon Mar  8 2004 mludvig@suse.cz
- Add sysconfig and init.d files.
* Fri Mar  5 2004 mludvig@suse.cz
- Include samples config files in the RPM.
* Thu Mar  4 2004 mludvig@suse.cz
- update to 0.3rc1
* Tue Feb  3 2004 mludvig@suse.cz
- Update to 0.2.4
* Mon Jan 26 2004 ro@suse.de
- updated neededforbuild "kernel-source-26" -> "kernel-source"
* Thu Jan 15 2004 mludvig@suse.cz
- update to ipsec-tools-0.2.3
* Sat Jan 10 2004 adrian@suse.de
- remove obsolete %%run_ldconfig
* Tue Dec 23 2003 mludvig@suse.cz
- Recognize IPSEC_DIR_FWD when dumping SPD.
* Fri Dec 19 2003 mludvig@suse.cz
- Added many fixes gathered from the mailing list.
- Added support for specifying SA lifebytes.
* Wed Dec 17 2003 garloff@suse.de
- Package ipsec-tools 0.2.2.
